@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #define BASIC_WIN32_DEBUGGING
 
@@ -503,23 +503,23 @@ dump_glyphs_and_log_clusters (gboolean rtl,
   {
     int j, k, nclusters, clusterix, charix, ng;
 
-    printf ("  ScriptShape: nglyphs=%d: ", nglyphs);
+    g_print ("  ScriptShape: nglyphs=%d: ", nglyphs);
 
     for (j = 0; j < nglyphs; j++)
-      printf ("%d%s", iglyphs[j], (j < nglyphs-1) ? "," : "");
-    printf ("\n");
+      g_print ("%d%s", iglyphs[j], (j < nglyphs-1) ? "," : "");
+    g_print ("\n");
 
-    printf ("  log_clusters: ");
+    g_print ("  log_clusters: ");
     for (j = 0; j < itemlen; j++)
-      printf ("%d ", log_clusters[j]);
-    printf ("\n");
+      g_print ("%d ", log_clusters[j]);
+    g_print ("\n");
     nclusters = 0;
     for (j = 0; j < itemlen; j++)
       {
 	if (j == 0 || log_clusters[j-1] != log_clusters[j])
 	  nclusters++;
       }
-    printf ("  %d clusters:\n", nclusters);
+    g_print ("  %d clusters:\n", nclusters);
 
     /* If RTL, first char is the last in the run, otherwise the
      * first.
@@ -531,22 +531,22 @@ dump_glyphs_and_log_clusters (gboolean rtl,
 	for (j = itemlen - 1, charix = charix0 + j; j >= 0; j--, charix--)
 	  {
 	    if (j == itemlen - 1 || log_clusters[j] != log_clusters[j+1])
-	      printf ("  Cluster %d: chars %d--",
-		      clusterix, charix);
+	      g_print ("  Cluster %d: chars %d--",
+		       clusterix, charix);
 	    if (j == 0 || log_clusters[j-1] != log_clusters[j])
 	      {
 		ng = log_clusters[j] - firstglyphix + 1;
-		printf ("%d: %d glyphs: ",
-			charix, ng);
+		g_print ("%d: %d glyphs: ",
+			 charix, ng);
 		for (k = firstglyphix; k <= log_clusters[j]; k++)
 		  {
-		    printf ("%d", iglyphs[k]);
+		    g_print ("%d", iglyphs[k]);
 		    if (k < log_clusters[j])
-		      printf (",");
+		      g_print (",");
 		  }
 		firstglyphix = log_clusters[j] + 1;
 		clusterix++;
-		printf ("\n");
+		g_print ("\n");
 	      }
 	  }
       }
@@ -555,22 +555,22 @@ dump_glyphs_and_log_clusters (gboolean rtl,
 	for (j = 0, charix = charix0; j < itemlen; j++, charix++)
 	  {
 	    if (j == 0 || log_clusters[j-1] != log_clusters[j])
-	      printf ("  Cluster %d: wchar_t %d--",
-		      clusterix, charix);
+	      g_print ("  Cluster %d: wchar_t %d--",
+		       clusterix, charix);
 	    if (j == itemlen - 1 || log_clusters[j] != log_clusters[j+1])
 	      {
 		int klim = ((j == itemlen-1) ? nglyphs : log_clusters[j+1]);
 		ng = klim - log_clusters[j];
-		printf ("%d: %d glyphs: ",
-			charix, ng);
+		g_print ("%d: %d glyphs: ",
+			 charix, ng);
 		for (k = log_clusters[j]; k < klim; k++)
 		  {
-		    printf ("%d", iglyphs[k]);
+		    g_print ("%d", iglyphs[k]);
 		    if (k != klim - 1)
-		      printf (",");
+		      g_print (",");
 		  }
 		clusterix++;
-		printf ("\n");
+		g_print ("\n");
 	      }
 	  }
       }
@@ -728,22 +728,22 @@ itemize_shape_and_place (PangoFont        *font,
   
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf (G_STRLOC ": ScriptItemize: uDefaultLanguage:%04x uBidiLevel:%d\n",
-	    control.uDefaultLanguage, state.uBidiLevel);
+    g_print (G_STRLOC ": ScriptItemize: uDefaultLanguage:%04x uBidiLevel:%d\n",
+	     control.uDefaultLanguage, state.uBidiLevel);
 #endif
   if ((*script_itemize) (wtext, wlen, G_N_ELEMENTS (items), &control, NULL,
 			 items, &nitems))
     {
 #ifdef BASIC_WIN32_DEBUGGING
       if (pango_win32_debug)
-	printf ("ScriptItemize failed\n");
+	g_print ("ScriptItemize failed\n");
 #endif
       return FALSE;
     }
 
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf ("%d items:\n", nitems);
+    g_print ("%d items:\n", nitems);
 #endif
 
   if (analysis->level % 2)
@@ -781,17 +781,17 @@ itemize_shape_and_place (PangoFont        *font,
 
 #ifdef BASIC_WIN32_DEBUGGING
       if (pango_win32_debug)
-	printf ("  Item %d: iCharPos=%d eScript=%d (%s) %s%s%s%s%s%s%s wchar_t %d--%d (%d)\n",
-		item, items[item].iCharPos, script,
-		lang_name (scripts[script]->langid),
-		scripts[script]->fComplex ? "complex" : "simple",
-		items[item].a.fRTL ? " fRTL" : "",
-		items[item].a.fLayoutRTL ? " fLayoutRTL" : "",
-		items[item].a.fLinkBefore ? " fLinkBefore" : "",
-		items[item].a.fLinkAfter ? " fLinkAfter" : "",
-		items[item].a.fLogicalOrder ? " fLogicalOrder" : "",
-		items[item].a.fNoGlyphIndex ? " fNoGlyphIndex" : "",
-		items[item].iCharPos, items[item+1].iCharPos-1, itemlen);
+	g_print ("  Item %d: iCharPos=%d eScript=%d (%s) %s%s%s%s%s%s%s wchar_t %d--%d (%d)\n",
+		 item, items[item].iCharPos, script,
+		 lang_name (scripts[script]->langid),
+		 scripts[script]->fComplex ? "complex" : "simple",
+		 items[item].a.fRTL ? " fRTL" : "",
+		 items[item].a.fLayoutRTL ? " fLayoutRTL" : "",
+		 items[item].a.fLinkBefore ? " fLinkBefore" : "",
+		 items[item].a.fLinkAfter ? " fLinkAfter" : "",
+		 items[item].a.fLogicalOrder ? " fLogicalOrder" : "",
+		 items[item].a.fNoGlyphIndex ? " fNoGlyphIndex" : "",
+		 items[item].iCharPos, items[item+1].iCharPos-1, itemlen);
 #endif
 
       items[item].a.fRTL = analysis->level % 2;
@@ -806,7 +806,7 @@ itemize_shape_and_place (PangoFont        *font,
 	{
 #ifdef BASIC_WIN32_DEBUGGING
 	  if (pango_win32_debug)
-	    printf ("pango-basic-win32: ScriptShape failed\n");
+	    g_print ("pango-basic-win32: ScriptShape failed\n");
 #endif
 	  return FALSE;
 	}
@@ -831,7 +831,7 @@ itemize_shape_and_place (PangoFont        *font,
 	{
 #ifdef BASIC_WIN32_DEBUGGING
 	  if (pango_win32_debug)
-	    printf ("pango-basic-win32: ScriptPlace failed\n");
+	    g_print ("pango-basic-win32: ScriptPlace failed\n");
 #endif
 	  return FALSE;
 	}
@@ -849,10 +849,10 @@ itemize_shape_and_place (PangoFont        *font,
 	    {
 	      PangoRectangle logical_rect;
 	      /* Should pass actual char that was not found to
-	       * pango_win32_get_unknown_glyph(), but a bit hard to
+	       * PANGO_GET_UNKNOWN_GLYPH(), but a bit hard to
 	       * find out that at this point, so cheat and use 0.
 	       */
-	      PangoGlyph unk = pango_win32_get_unknown_glyph (font, 0);
+	      PangoGlyph unk = PANGO_GET_UNKNOWN_GLYPH (0);
 
 	      glyphs->glyphs[ng+glyphix].glyph = unk;
 	      pango_font_get_glyph_extents (font, unk, NULL, &logical_rect);
@@ -866,10 +866,10 @@ itemize_shape_and_place (PangoFont        *font,
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
     {
-      printf ("  Pango log_clusters (level:%d), char index:", analysis->level);
+      g_print ("  Pango log_clusters (level:%d), char index:", analysis->level);
       for (glyphix = 0; glyphix < glyphs->num_glyphs; glyphix++)
-	printf ("%d ", glyphs->log_clusters[glyphix]);
-      printf ("\n");
+	g_print ("%d ", glyphs->log_clusters[glyphix]);
+      g_print ("\n");
     }
 #endif
 
@@ -913,10 +913,10 @@ uniscribe_shape (PangoFont        *font,
 	{
 	  int glyphix;
 
-	  printf ("  Pango log_clusters, byte offsets:");
+	  g_print ("  Pango log_clusters, byte offsets:");
 	  for (glyphix = 0; glyphix < glyphs->num_glyphs; glyphix++)
-	    printf ("%d ", glyphs->log_clusters[glyphix]);
-	  printf ("\n");
+	    g_print ("%d ", glyphs->log_clusters[glyphix]);
+	  g_print ("\n");
 	}
 #endif
     }
@@ -946,8 +946,8 @@ text_is_simple (const char *text,
 
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf ("text_is_simple: %.*s (%ld wchar_t): %s\n",
-	    MIN (length, 10), text, wlen, retval ? "YES" : "NO");
+    g_print ("text_is_simple: %.*s (%ld wchar_t): %s\n",
+	     MIN (length, 10), text, wlen, retval ? "YES" : "NO");
 #endif
 
   return retval;
@@ -1003,7 +1003,7 @@ basic_engine_shape (PangoEngineShape *engine,
 		
       if (pango_is_zero_width (wc))
 	{
-	  set_glyph (font, glyphs, i, p - text, 0);
+	  set_glyph (font, glyphs, i, p - text, PANGO_GLYPH_EMPTY);
 	}
       else
 	{
@@ -1034,7 +1034,7 @@ basic_engine_shape (PangoEngineShape *engine,
 		}
 	    }
 	  else
-	    set_glyph (font, glyphs, i, p - text, pango_win32_get_unknown_glyph (font, wc));
+	    set_glyph (font, glyphs, i, p - text, PANGO_GET_UNKNOWN_GLYPH (wc));
 	}
       
       p = g_utf8_next_char (p);
