@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -49,6 +50,8 @@ struct _PangoXftFontMap
   PangoXftSubstituteFunc substitute_func;
   gpointer substitute_data;
   GDestroyNotify substitute_destroy;
+
+  PangoRenderer *renderer;
 };
 
 struct _PangoXftFontMapClass
@@ -56,44 +59,15 @@ struct _PangoXftFontMapClass
   PangoFcFontMapClass parent_class;
 };
 
-static void          pango_xft_font_map_class_init         (PangoXftFontMapClass *class);
 static void          pango_xft_font_map_default_substitute (PangoFcFontMap       *fcfontmap,
 							    FcPattern            *pattern);
 static PangoFcFont * pango_xft_font_map_new_font           (PangoFcFontMap       *fcfontmap,
 							    FcPattern            *pattern);
 static void          pango_xft_font_map_finalize           (GObject              *object);
 
-static GObjectClass *parent_class;
-
 static GSList *fontmaps = NULL;
 
-GType
-pango_xft_font_map_get_type (void)
-{
-  static GType object_type = 0;
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info =
-      {
-        sizeof (PangoXftFontMapClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) pango_xft_font_map_class_init,
-        NULL,           /* class_finalize */
-        NULL,           /* class_data */
-        sizeof (PangoXftFontMap),
-        0,              /* n_preallocs */
-        (GInstanceInitFunc) NULL,
-      };
-      
-      object_type = g_type_register_static (PANGO_TYPE_FC_FONT_MAP,
-                                            "PangoXftFontMap",
-                                            &object_info, 0);
-    }
-  
-  return object_type;
-}
+G_DEFINE_TYPE (PangoXftFontMap, pango_xft_font_map, PANGO_TYPE_FC_FONT_MAP)
 
 static void
 pango_xft_font_map_class_init (PangoXftFontMapClass *class)
@@ -101,24 +75,30 @@ pango_xft_font_map_class_init (PangoXftFontMapClass *class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   PangoFcFontMapClass *fcfontmap_class = PANGO_FC_FONT_MAP_CLASS (class);
 
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class->finalize  = pango_xft_font_map_finalize;
   fcfontmap_class->default_substitute = pango_xft_font_map_default_substitute;
   fcfontmap_class->new_font = pango_xft_font_map_new_font;
 }
 
+static void
+pango_xft_font_map_init (PangoXftFontMap *xftfontmap)
+{
+}
+
 static void
 pango_xft_font_map_finalize (GObject *object)
 {
   PangoXftFontMap *xftfontmap = PANGO_XFT_FONT_MAP (object);
   
+  if (xftfontmap->renderer)
+    g_object_unref (xftfontmap->renderer);
+
   fontmaps = g_slist_remove (fontmaps, object);
 
   if (xftfontmap->substitute_destroy)
     xftfontmap->substitute_destroy (xftfontmap->substitute_data);
 
-  parent_class->finalize (object);
+  G_OBJECT_CLASS (pango_xft_font_map_parent_class)->finalize (object);
 }
 
 
@@ -234,7 +214,9 @@ pango_xft_get_font_map (Display *display,
  * @screen: the screen number of a screen within @display
  * 
  * Release any resources that have been cached for the
- * combination of @display and @screen.
+ * combination of @display and @screen. Note that when the
+ * X display is closed, resources are released automatically,
+ * without needing to call this function.
  *
  * Since: 1.2
  **/
@@ -349,16 +331,42 @@ pango_xft_get_context (Display *display,
   return pango_fc_font_map_create_context (PANGO_FC_FONT_MAP (fontmap));
 }
 
+/**
+ * _pango_xft_font_map_get_renderer:
+ * @fontmap: a #PangoXftFontmap
+ * 
+ * Gets the singleton PangoXFTRenderer for this fontmap.
+ * 
+ * Return value: 
+ **/
+PangoRenderer *
+_pango_xft_font_map_get_renderer (PangoXftFontMap *xftfontmap)
+{
+  if (!xftfontmap->renderer)
+    xftfontmap->renderer = pango_xft_renderer_new (xftfontmap->display,
+						   xftfontmap->screen);
+
+  return xftfontmap->renderer;
+}
+
 static void
 pango_xft_font_map_default_substitute (PangoFcFontMap *fcfontmap,
 				       FcPattern      *pattern)
 {
   PangoXftFontMap *xftfontmap = PANGO_XFT_FONT_MAP (fcfontmap);
+  double d;
 	
   FcConfigSubstitute (NULL, pattern, FcMatchPattern);
   if (xftfontmap->substitute_func)
     xftfontmap->substitute_func (pattern, xftfontmap->substitute_data);
   XftDefaultSubstitute (xftfontmap->display, xftfontmap->screen, pattern);
+  if (FcPatternGetDouble (pattern, FC_PIXEL_SIZE, 0, &d) == FcResultMatch && d == 0.0)
+    {
+      FcValue v;
+      v.type = FcTypeDouble;
+      v.u.d = 1.0;
+      FcPatternAdd (pattern, FC_PIXEL_SIZE, v, FcFalse);
+    }
 }
 
 static PangoFcFont *
